keyring

package
v0.0.17-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package keyring is a simple wrapper that adds timeouts to the zalando/go-keyring package.

Index

Constants

This section is empty.

Variables

var (
	ErrNotFound = errors.New("secret not found in keyring")
	ErrTimeout  = errors.New("timeout while accessing keyring")
)

Functions

func Delete

func Delete(service, user string, timeout time.Duration) error

Delete secret from keyring.

func DeleteAll

func DeleteAll(service string, timeout time.Duration) error

func Get

func Get(service, user string, timeout time.Duration) (string, error)

Get secret from keyring given service and user name.

func Set

func Set(service, user, secret string, timeout time.Duration) error

Set secret in keyring for user.

Types

This section is empty.

Jump to